==> dl.php?src=linea21_1_8.zip: linea21/languages/es/lang_yellowpages.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['yp']['section'] = "directorio de organizaciones";

/*	nommage des modules
 *  	*/
$lang['yp']['name']="organización";
$lang['yp']['confirm_add'] = "organización añadida correctamente";
$lang['yp']['confirm_mod'] = "organización actualizada correctamente";
$lang['yp']['confirm_sup'] ="organización eliminada correctamente";
$lang['yp']['confirm_pub']= "Organización añadida correctamente. Su registro sera validado por el administrador con la mayor brevedad posible";
$lang['yp']['confirm_pub2']= "Haga click para volver al directorio";
/*	nommage rubrique module
 *  	*/
$lang['yp']['add']= "Añadir nueva ".$lang['yp']['name'];
$lang['yp']['mod']= "Editar ".$lang['yp']['name'];
$lang['yp']['sup']= "Eliminar ".$lang['yp']['name'];
$lang['yp']['det']= ucfirst($lang['yp']['name']) . " detalles";
$lang['yp']['list']= "Ver directorio ";
$lang['yp']['nb_total']='organización(es) registrada(s)';

/*	publique
 *  	*/
$lang['yp']['add_public']= "Agregue su ".$lang['yp']['name'];
$lang['yp']['h1_public_comment']='El directorio está dirigido a todas aquellas organzaciones relacionadas con el desarrollo sostenible y con la '. SITE_NAME.'. Si desea formar parte del directorio, haga click en el enlace "Agregue su organización" e introduzca sus datos.';
$lang['yp']['h1_public_add']='El registro de su organización es libre. Complete el formulario y recibirá un email cuando el registro sea efectivo (se requiere validación del administrador).';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['yp']['add_title']="Añadir valores a la nueva ".$lang['yp']['name'];
$lang['yp']['mod_title']="Editar valores de la ".$lang['yp']['name'];
$lang['yp']['recap_commment']="sin comentarios";
$lang['yp']['confirmation']="subscripción confirmada";
$lang['yp']['actions']='acciones';


/*	nommage email
 *  	*/
$lang['yp']['mail_body1']="Your registration is now confirmed. You can access the entry by following this link : "; // @todo translation
$lang['yp']['confirm_subscription']='Your organisation is now listed in the directory'; // @todo translation
$lang['yp']['mail_subject_added']="Your organisation has been added to the directory";
$lang['yp']['mail_body_added1']="We added your organisation in our directory.<br /><br />\n\nYou can access it by following the URL : ";  // @todo translation
$lang['yp']['mail_body_added2']="If you want us to remove the entry please contact us.\n"; // @todo translation

/*	nommage rubrique sup
 *  	*/
$lang['yp']['sup_yp_warning']="Esta seguro de que desea eliminar esta ".$lang['yp']['name']." ?";


/*	nommage élément rubrique
 *  	*/

$lang['yp']['name2']="nombre";
$lang['yp']['activity']="actividad";
$lang['yp']['street']="calle";
$lang['yp']['postal_code']="código postal";
$lang['yp']['infos_adresse']="dirección postal e información complementaria";
$lang['yp']['adresse']="dirección";
$lang['yp']['city']="ciudad";
$lang['yp']['country']="país";
$lang['yp']['phone']="teléfono";
$lang['yp']['fax']="fax";
$lang['yp']['email']="email";
$lang['yp']['website']="sitio web";
$lang['yp']['theme']="área asociada";


/*	nommage quickbox
 *  	*/
$lang['yp']['qb_title']=" organizaciones modificadas recientemente";


/*	divers
 *  	*/
$lang['yp']['select_choice']="-- Seleccionar de la lista --";
$lang['yp']['facultatif']="opcional";
$lang['yp']['theme_filter']="Mostrar por área";
$lang['yp']['notheme']="No consta";
$lang['yp']['title_theme']="organizaciones con area";
$lang['yp']['title_statut']="organizaciones con estado";
$lang['yp']['statut_filter']="Mostrar por estado";
$lang['yp']['preinscription']="Pre-registros";
$lang['yp']['all']="Mostrar directorio completo";
$lang['yp']['draft']="pre-registrado";
$lang['yp']['noresult']="No existen organizaciones con este criterio.";
$lang['yp']['alphabetical']=' [A-Z] ';


/*	messages
 *  	*/


$lang['yp']['object_notname']="El nombre es requerido.";
$lang['yp']['object_notactivity']="La actividad es requerida.";
$lang['yp']['object_notstreet']="La calle es requerida.";
$lang['yp']['object_notpostal_code']="El código postal es requerido.";
$lang['yp']['object_notcity']="La ciudad es requerida.";
$lang['yp']['object_notcountry']="El país es requerido.";
$lang['yp']['object_notemail']="El email introducido no es válido.";
$lang['yp']['object_notphone']="El teléfono introducido no es válido.";
$lang['yp']['object_notfax']="El fax introducido no es válido.";
$lang['yp']['invalid_protocol']='Protocolo no válido, por favor revise la sintaxis';


/*	rubrique d'aide
 *  	*/
$lang['yp']['help_add1']="Para añadir una nueva organización, inserte la información requerida en el formulario.";
$lang['yp']['help_add2']="Completado el formulario, revise los valores en el resumen.";
$lang['yp']['help_add3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';


$lang['yp']['help_list1']="Para mas información haga click en el nombre de la organización.";
$lang['yp']['help_list2']="Para eliminar una organización, haga click en el icono 'eliminar organización'.";
$lang['yp']['help_list3']="Para editar una organización, haga click en el icono 'editar organizaciónC.";
$lang['yp']['help_list4']="Para añadir una nueva organización, haga click en 'añadir nueva organización'.";
$lang['yp']['help_list5']="Si desea realizar una búsqueda dentro del módulo 'directorio', haga click en 'buscar'.";
$lang['yp']['help_list6']="Para visualizar las organizaciones por orden alfabético, mostrar por orden alfabético.";
$lang['yp']['help_list7']="Para visualizar las organizaciones por estado, mostrar por estados.";
$lang['yp']['help_list8']="Para ver las organizaciones pre-registradas, seleccione el estado 'pre-registros'.";
$lang['yp']['help_list9']="Para validar un pre-registro haga click en el icono correspondiente.";
$lang['yp']['help_list10']="El estado 'archivo privado' le permite mantener en el directorio organizaciones que no tienen acceso público.";




$lang['yp']['help_mod1']="Para editar una organización, inserte la información requerida en el formulario.";

$lang['yp']['help_mod2']="Completado el formulario, revise los valores en el resumen.";
$lang['yp']['help_mod3']='Revisado el resumen, haga click en "revisar valores" si desea realizar cambios.';
$lang['yp']['help_mod4']="El estado del archivo le permite mantener en el directorio organizaciones que no tienen acceso público.";




$lang['yp']['help_det1']="Para editar una organización haga click en el icono 'editar organización'.";
$lang['yp']['help_det2']="Para eliminar una organización haga click en el icono 'eliminar organización'.";
$lang['yp']['help_det3']="Para más información sobre el área de la organización, haga click en el área.";
$lang['yp']['help_det4']="Para añadir una organización al directorio, haga click en 'validar pre-registro'.  Se enviará un email a la organización automáticamente.";


$lang['yp']['help_sup1']="Para eliminar una organización, haga click en el icono 'eliminar organización'.";
$lang['yp']['help_sup2']="Se eliminarán también los pre-registros de esta página.";
?>

==> dl.php?src=linea21_2_0_0.zip: linea21/languages/es/lang_yellowpages.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['yp']['section'] = "directorio de organizaciones";

/*	nommage des modules
 *  	*/
$lang['yp']['name']="organización";
$lang['yp']['confirm_add'] = "organización añadida correctamente";
$lang['yp']['confirm_mod'] = "organización actualizada correctamente";
$lang['yp']['confirm_sup'] ="organización eliminada correctamente";
$lang['yp']['confirm_pub']= "Organización añadida correctamente. Su registro sera validado por el administrador con la mayor brevedad posible";
$lang['yp']['confirm_pub2']= "Haga click para volver al directorio";
/*	nommage rubrique module
 *  	*/
$lang['yp']['add']= "Añadir nueva ".$lang['yp']['name'];
$lang['yp']['mod']= "Editar ".$lang['yp']['name'];
$lang['yp']['sup']= "Eliminar ".$lang['yp']['name'];
$lang['yp']['det']= ucfirst($lang['yp']['name']) . " detalles";
$lang['yp']['list']= "Ver directorio ";
$lang['yp']['nb_total']='organización(es) registrada(s)';

/*	publique
 *  	*/
$lang['yp']['add_public']= "Agregue su ".$lang['yp']['name'];
$lang['yp']['h1_public_comment']='El directorio está dirigido a todas aquellas organzaciones relacionadas con el desarrollo sostenible y con la '. SITE_NAME.'. Si desea formar parte del directorio, haga click en el enlace "Agregue su organización" e introduzca sus datos.';
$lang['yp']['h1_public_add']='El registro de su organización es libre. Complete el formulario y recibirá un email cuando el registro sea efectivo (se requiere validación del administrador).';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['yp']['add_title']="Añadir valores a la nueva ".$lang['yp']['name'];
$lang['yp']['mod_title']="Editar valores de la ".$lang['yp']['name'];
$lang['yp']['recap_commment']="sin comentarios";
$lang['yp']['confirmation']="subscripción confirmada";
$lang['yp']['actions']='acciones';


/*	nommage email
 *  	*/
$lang['yp']['mail_body1']="Your registration is now confirmed. You can access the entry by following this link : "; // @todo translation
$lang['yp']['confirm_subscription']='Your organisation is now listed in the directory'; // @todo translation
$lang['yp']['mail_subject_added']="Your organisation has been added to the directory";
$lang['yp']['mail_body_added1']="We added your organisation in our directory.<br /><br />\n\nYou can access it by following the URL : ";  // @todo translation
$lang['yp']['mail_body_added2']="If you want us to remove the entry please contact us.\n"; // @todo translation

/*	nommage rubrique sup
 *  	*/
$lang['yp']['sup_yp_warning']="Esta seguro de que desea eliminar esta ".$lang['yp']['name']." ?";


/*	nommage élément rubrique
 *  	*/

$lang['yp']['name2']="nombre";
$lang['yp']['activity']="actividad";
$lang['yp']['street']="calle";
$lang['yp']['postal_code']="código postal";
$lang['yp']['infos_adresse']="dirección postal e información complementaria";
$lang['yp']['adresse']="dirección";
$lang['yp']['city']="ciudad";
$lang['yp']['country']="país";
$lang['yp']['phone']="teléfono";
$lang['yp']['fax']="fax";
$lang['yp']['email']="email";
$lang['yp']['website']="sitio web";
$lang['yp']['level']="nivel asociado";


/*	nommage quickbox
 *  	*/
$lang['yp']['qb_title']=" organizaciones modificadas recientemente";


/*	divers
 *  	*/
$lang['yp']['select_choice']="-- Seleccionar de la lista --";
$lang['yp']['facultatif']="opcional";
$lang['yp']['nolevel']="No nivel";
$lang['yp']['title_level']="organizaciones con nivel";
$lang['yp']['title_statut']="organizaciones con estado";
$lang['yp']['statut_filter']="Mostrar por estado";
$lang['yp']['preinscription']="Pre-registros";
$lang['yp']['all']="Mostrar directorio completo";
$lang['yp']['draft']="pre-registrado";
$lang['yp']['noresult']="No existen organizaciones con este criterio.";
$lang['yp']['alphabetical']=' [A-Z] ';


/*	messages
 *  	*/


$lang['yp']['object_notname']="El nombre es requerido.";
$lang['yp']['object_notactivity']="La actividad es requerida.";
$lang['yp']['object_notstreet']="La calle es requerida.";
$lang['yp']['object_notpostal_code']="El código postal es requerido.";
$lang['yp']['object_notcity']="La ciudad es requerida.";
$lang['yp']['object_notcountry']="El país es requerido.";
$lang['yp']['object_notemail']="El email introducido no es válido.";
$lang['yp']['object_notphone']="El teléfono introducido no es válido.";
$lang['yp']['object_notfax']="El fax introducido no es válido.";
$lang['yp']['invalid_protocol']='Protocolo no válido, por favor revise la sintaxis';


/*	rubrique d'aide
 *  	*/
$lang['yp']['help_add1']="Para añadir una nueva organización, inserte la información requerida en el formulario.";
$lang['yp']['help_add2']="Completado el formulario, revise los valores en el resumen.";
$lang['yp']['help_add3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';


$lang['yp']['help_list1']="Para mas información haga click en el nombre de la organización.";
$lang['yp']['help_list2']="Para eliminar una organización, haga click en el icono 'eliminar organización'.";
$lang['yp']['help_list3']="Para editar una organización, haga click en el icono 'editar organización'.";
$lang['yp']['help_list4']="Para añadir una nueva organización, haga click en 'añadir nueva organización'.";
$lang['yp']['help_list5']="Si desea realizar una búsqueda dentro del módulo 'directorio', haga click en 'buscar'.";
$lang['yp']['help_list6']="Para visualizar las organizaciones por orden alfabético, mostrar por orden alfabético.";
$lang['yp']['help_list7']="Para visualizar las organizaciones por estado, mostrar por estados.";
$lang['yp']['help_list8']="Para ver las organizaciones pre-registradas, seleccione el estado 'pre-registros'.";
$lang['yp']['help_list9']="Para validar un pre-registro haga click en el icono correspondiente.";
$lang['yp']['help_list10']="El estado 'archivo privado' le permite mantener en el directorio organizaciones que no tienen acceso público.";




$lang['yp']['help_mod1']="Para editar una organización, inserte la información requerida en el formulario.";

$lang['yp']['help_mod2']="Completado el formulario, revise los valores en el resumen.";
$lang['yp']['help_mod3']='Revisado el resumen, haga click en "revisar valores" si desea realizar cambios.';
$lang['yp']['help_mod4']="El estado del archivo le permite mantener en el directorio organizaciones que no tienen acceso público.";




$lang['yp']['help_det1']="Para editar una organización haga click en el icono 'editar organización'.";
$lang['yp']['help_det2']="Para eliminar una organización haga click en el icono 'eliminar organización'.";
$lang['yp']['help_det3']="Para más información sobre el nivel de la organización, haga click en el nivel.";
$lang['yp']['help_det4']="Para añadir una organización al directorio, haga click en 'validar pre-registro'.  Se enviará un email a la organización automáticamente.";


$lang['yp']['help_sup1']="Para eliminar una organización, haga click en el icono 'eliminar organización'.";
$lang['yp']['help_sup2']="Se eliminarán también los pre-registros de esta página.";
?>
